@@ -1,9 +1,10 @@
+"""Nomad Evaluations: https://developer.hashicorp.com/nomad/api-docs/evaluations"""
 import nomad.api.exceptions
 
 from nomad.api.base import Requester
 
-class Evaluations(Requester):
 
+class Evaluations(Requester):
     """
     The evaluations endpoint is used to query the status of evaluations.
     By default, the agent's local region is used; another region can
@@ -11,16 +12,17 @@ class Evaluations(Requester):
 
     https://www.nomadproject.io/docs/http/evals.html
     """
+
     ENDPOINT = "evaluations"
 
     def __init__(self, **kwargs):
-        super(Evaluations, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def __str__(self):
-        return "{0}".format(self.__dict__)
+        return f"{self.__dict__}"
 
     def __repr__(self):
-        return "{0}".format(self.__dict__)
+        return f"{self.__dict__}"
 
     def __getattr__(self, item):
         raise AttributeError
@@ -29,11 +31,11 @@ class Evaluations(Requester):
         try:
             evaluations = self.get_evaluations()
 
-            for e in evaluations:
-                if e["ID"] == item:
+            for evaluation in evaluations:
+                if evaluation["ID"] == item:
                     return True
-            else:
-                return False
+
+            return False
         except nomad.api.exceptions.URLNotFoundNomadException:
             return False
 
@@ -45,29 +47,28 @@ class Evaluations(Requester):
         try:
             evaluations = self.get_evaluations()
 
-            for e in evaluations:
-                if e["ID"] == item:
-                    return e
-            else:
-                raise KeyError
-        except nomad.api.exceptions.URLNotFoundNomadException:
+            for evaluation in evaluations:
+                if evaluation["ID"] == item:
+                    return evaluation
             raise KeyError
+        except nomad.api.exceptions.URLNotFoundNomadException as exc:
+            raise KeyError from exc
 
     def __iter__(self):
         evaluations = self.get_evaluations()
         return iter(evaluations)
 
     def get_evaluations(self, prefix=None):
-        """ Lists all the evaluations.
+        """Lists all the evaluations.
 
-           https://www.nomadproject.io/docs/http/evals.html
-            arguments:
-              - prefix :(str) optional, specifies a string to filter evaluations on based on an prefix.
-                        This is specified as a querystring parameter.
-            returns: list
-            raises:
-              - nomad.api.exceptions.BaseNomadException
-              - nomad.api.exceptions.URLNotFoundNomadException
+        https://www.nomadproject.io/docs/http/evals.html
+        arguments:
+          - prefix :(str) optional, specifies a string to filter evaluations on based on an prefix.
+                    This is specified as a querystring parameter.
+        returns: list
+        raises:
+          - nomad.api.exceptions.BaseNomadException
+          - nomad.api.exceptions.URLNotFoundNomadException
         """
         params = {"prefix": prefix}
         return self.request(method="get", params=params).json()
