@@ -1,8 +1,8 @@
+"""Nomad Metrics: https://developer.hashicorp.com/nomad/api-docs/metrics"""
 from nomad.api.base import Requester
 
 
 class Metrics(Requester):
-
     """
     The /metrics endpoint returns metrics for the current Nomad process.
 
@@ -12,28 +12,30 @@ class Metrics(Requester):
 
     https://www.nomadproject.io/docs/agent/telemetry.html
     """
+
     ENDPOINT = "metrics"
 
     def __init__(self, **kwargs):
-        super(Metrics, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def __str__(self):
-        return "{0}".format(self.__dict__)
+        return f"{self.__dict__}"
 
     def __repr__(self):
-        return "{0}".format(self.__dict__)
+        return f"{self.__dict__}"
 
     def __getattr__(self, item):
-        raise AttributeError
+        msg = f"{item} does not exist"
+        raise AttributeError(msg)
 
     def get_metrics(self):
-        """ Get the metrics
+        """Get the metrics
 
-           https://www.nomadproject.io/api/metrics.html
+        https://www.nomadproject.io/api/metrics.html
 
-            returns: dict
-            raises:
-              - nomad.api.exceptions.BaseNomadException
-              - nomad.api.exceptions.URLNotFoundNomadException
+        returns: dict
+        raises:
+          - nomad.api.exceptions.BaseNomadException
+          - nomad.api.exceptions.URLNotFoundNomadException
         """
         return self.request(method="get").json()
